changeset 14960:c959136f8c3e

Rename jit_check_error to jit_error_check * src/pt-jit.h (JIT_VISIT_IR_NOTEMPLATE, jit_check_error): Replace check_error with error_check. * src/pt-jit.cc (jit_convert::visit_binary_expression, jit_convert::visit_if_command_list, jit_convert::remove_dead, jit_convert::convert_llvm::visit): Replace check_error with error_check.
author Max Brister <max@2bass.com>
date Tue, 19 Jun 2012 12:36:53 -0500
parents 12fd4a62d633
children 903a5ee2cdde
files src/pt-jit.cc src/pt-jit.h
diffstat 2 files changed, 8 insertions(+), 8 deletions(-) [+]
line wrap: on
line diff
--- a/src/pt-jit.h	Tue Jun 19 12:27:55 2012 -0500
+++ b/src/pt-jit.h	Tue Jun 19 12:36:53 2012 -0500
@@ -709,7 +709,7 @@
   JIT_METH(store_argument);                     \
   JIT_METH(phi);                                \
   JIT_METH(variable);                           \
-  JIT_METH(check_error);                        \
+  JIT_METH(error_check);                        \
   JIT_METH(assign)                              \
   JIT_METH(argument)
 
@@ -1782,10 +1782,10 @@
 // checks error_state, if error_state is false then goto the normal branche,
 // otherwise goto the error branch
 class
-jit_check_error : public jit_terminator
+jit_error_check : public jit_terminator
 {
 public:
-  jit_check_error (jit_call *acheck_for, jit_block *normal, jit_block *error)
+  jit_error_check (jit_call *acheck_for, jit_block *normal, jit_block *error)
     : jit_terminator (2, error, normal, acheck_for) {}
 
   jit_call *check_for (void) const
--- a/src/pt-jit.cc	Tue Jun 19 12:27:55 2012 -0500
+++ b/src/pt-jit.cc	Tue Jun 19 12:36:53 2012 -0500
@@ -1618,7 +1618,7 @@
   jit_call *call = block->append (create<jit_call> (fn, lhsv, rhsv));
 
   jit_block *normal = create<jit_block> (block->name ());
-  block->append (create<jit_check_error> (call, normal, final_block));
+  block->append (create<jit_error_check> (call, normal, final_block));
   add_block (normal);
   block = normal;
   result = call;
@@ -1875,7 +1875,7 @@
 
           jit_block *next = create<jit_block> (block->name ());
           add_block (next);
-          block->append (create<jit_check_error> (check, next, final_block));
+          block->append (create<jit_error_check> (check, next, final_block));
           block = next;
 
           jit_block *body = create<jit_block> (i == 0 ? "if_body"
@@ -1940,7 +1940,7 @@
   block->append (call);
 
   jit_block *normal = create<jit_block> (block->name ());
-  block->append (create<jit_check_error> (call, normal, final_block));
+  block->append (create<jit_error_check> (call, normal, final_block));
   add_block (normal);
   block = normal;
   result = call;
@@ -2350,7 +2350,7 @@
       jit_block *b = *biter;
       if (b->alive ())
         {
           // FIXME: A special case for jit_check_error, if we generalize to
           // we will need to change!
           jit_terminator *term = b->terminator ();
           if (term && term->successor_count () == 2 && ! term->alive (0))
@@ -2689,7 +2689,7 @@
 }
 
 void
-jit_convert::convert_llvm::visit (jit_check_error& check)
+jit_convert::convert_llvm::visit (jit_error_check& check)
 {
   llvm::Value *cond = jit_typeinfo::insert_error_check ();
   llvm::Value *br = builder.CreateCondBr (cond, check.successor_llvm (0),
@@ -2350,7 +2350,7 @@
       if (b->alive ())
         {
-          // FIXME: A special case for jit_check_error, if we generalize to
+          // FIXME: A special case for jit_error_check, if we generalize to
           // we will need to change!
           jit_terminator *term = b->terminator ();